# Enable or disable running the tests
%global tests 0

Name:           kitty
Version:        0.19.3
Release:        %mkrel 1
Summary:        A cross-platform, fast, feature full, GPU based terminal emulator
Group:          Terminals
License:        GPLv3
URL:            https://sw.kovidgoyal.net/kitty/
Source0:        https://github.com/kovidgoyal/kitty/releases/download/v%{version}/%{name}-%{version}.tar.xz
# kitty.conf created by kekepower.
# Default is located in /etc/xdg/kitty/kitty.conf
Source1:        kitty.conf

BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(xkbcommon-x11)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  fontconfig
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  python3dist(pillow)
BuildRequires:  wayland-devel
BuildRequires:  wayland-protocols-devel
BuildRequires:  wayland-tools
BuildRequires:  pkgconfig(lcms2)
%if %{tests}
# This is required to run the tests
BuildRequires:  texlive-fontsextra
%endif
# ImageMagick is needed to resize the app icon to all sizes
BuildRequires:  imagemagick

Requires:       harfbuzz
Requires:       freetype2
Requires:       fontconfig
Requires:       %{_lib}canberra-gtk3_0
Requires:       imagemagick
Requires:       python3dist(pygments)
Requires:       %{name}-terminfo = %{version}-%{release}
Recommends:     %{name}-docs = %{version}-%{release}

%description
kitty is a cross-platform, fast, feature full, GPU based terminal emulator.

It is designed for power keyboard users. To that end all its controls work
with the keyboard (although it fully supports mouse interactions as well).
Its configuration is a simple, human editable, single file for easy
reproducibility (I like to store configuration in source control).

Finally, kitty is designed from the ground up to support all modern terminal
features, such as unicode, true color, bold/italic fonts, text formatting,
etc. It even extends existing text formatting escape codes, to add support
for features not available elsewhere, such as colored and styled (curly)
underlines. One of the design goals of kitty is to be easily extensible so
that new features can be added in the future with relatively little effort.

%package terminfo
Summary:       Terminfo for %{name}
Group:         Terminals
License:       GPLv3
BuildArch:     noarch

%description terminfo
Terminal info for %{name}.

You can install this package on, for example, servers you want to log on to
remotely to enable all the features available in %{name} without having to
install the whole program.

%package docs
Summary:       Documentation for %{name}
Group:         Terminals
License:       GPLv3
BuildArch:     noarch

%Description docs
%{summary}.

%prep
%autosetup

%build
# We want to control when to update this package and that is done with the
# option "--update-check-interval=0"
%{__python3} setup.py linux-package \
    --prefix %{_real_vendor}-%{_arch} \
    --update-check-interval=0 \
    --verbose \
    --debug \
    --libdir-name %{_lib}

# Fix the path to Python 3
pathfix.py -pni "%{__python3} %{py3_shbang_opts}" \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/__main__.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/show_error/main.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/hints/main.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/runner.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/resize_window/main.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/diff/search.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/diff/render.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/diff/patch.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/diff/main.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/diff/highlight.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/diff/config_data.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/diff/config.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/diff/collect.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/unicode_input/main.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/panel/main.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/clipboard/main.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/tui/operations.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/tui/loop.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/tui/line_edit.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/tui/images.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/tui/handler.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/key_demo/main.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/choose/main.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/ssh/main.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/icat/main.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kittens/ask/main.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/conf/utils.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/conf/definition.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/window.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/utils.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/update_check.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/terminfo.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/tabs.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/tab_bar.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/shell.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/session.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/rgb.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/remote_control.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/notify.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/marks.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/main.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/launch.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/keys.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/key_names.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/key_encoding.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/constants.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/config_data.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/config.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/complete.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/client.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/cli.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/choose_entry.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/child.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/boss.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/borders.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/fonts/render.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/fonts/list.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/fonts/fontconfig.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/fonts/core_text.py \
%{_real_vendor}-%{_arch}/%{_lib}/kitty/kitty/fonts/box_drawing.py

# Convert the app icon to all the sizes
%__mkdir_p %{_real_vendor}-%{_arch}/share/icons/hicolor/16x16/apps
%__mkdir_p %{_real_vendor}-%{_arch}/share/icons/hicolor/32x32/apps
%__mkdir_p %{_real_vendor}-%{_arch}/share/icons/hicolor/64x64/apps
%__mkdir_p %{_real_vendor}-%{_arch}/share/icons/hicolor/128x128/apps
%__mkdir_p %{_real_vendor}-%{_arch}/share/icons/hicolor/256x256/apps
%__mkdir_p %{_real_vendor}-%{_arch}/share/icons/hicolor/512x512/apps

convert logo/kitty.iconset/icon_512x512.png \
  -resize 64x64 logo/kitty.iconset/icon_64x64.png
cp logo/kitty.iconset/icon_16x16.png \
  %{_real_vendor}-%{_arch}/share/icons/hicolor/16x16/apps/%{name}.png
cp logo/kitty.iconset/icon_32x32.png \
  %{_real_vendor}-%{_arch}/share/icons/hicolor/32x32/apps/%{name}.png
cp logo/kitty.iconset/icon_64x64.png \
  %{_real_vendor}-%{_arch}/share/icons/hicolor/64x64/apps/%{name}.png
cp logo/kitty.iconset/icon_128x128.png \
  %{_real_vendor}-%{_arch}/share/icons/hicolor/128x128/apps/%{name}.png
cp logo/kitty.iconset/icon_256x256.png \
  %{_real_vendor}-%{_arch}/share/icons/hicolor/256x256/apps/%{name}.png
cp logo/kitty.iconset/icon_512x512.png \
  %{_real_vendor}-%{_arch}/share/icons/hicolor/512x512/apps/%{name}.png

%install
%__mkdir_p %{buildroot}%{_prefix}
cp -af %{_real_vendor}-%{_arch}/* %{buildroot}%{_prefix}

%__mkdir_p %{buildroot}%{_sysconfdir}/xdg/%{name}
cp %{S:1} %{buildroot}%{_sysconfdir}/xdg/%{name}/%{name}.conf

%if %{tests}
%check
%{__python3} setup.py test
%endif

%files
%license LICENSE
%doc README.asciidoc
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*
%{_libdir}/%{name}/
%config(noreplace) %{_sysconfdir}/xdg/%{name}/%{name}.conf
%exclude %{_mandir}/man1/%{name}.1*
%exclude %{_datadir}/doc/%{name}/html/
%exclude %{_datadir}/terminfo/x/xterm-kitty

%files docs
%{_mandir}/man1/%{name}.1*
%{_datadir}/doc/%{name}/html/


%files terminfo
%{_datadir}/terminfo/x/xterm-kitty


%changelog
* Tue Dec 22 2020 kekepower <kekepower> 0.19.3-1.mga8
+ Revision: 1662696
- Update to version 0.19.3

* Fri Nov 13 2020 kekepower <kekepower> 0.19.2-1.mga8
+ Revision: 1644901
- Update to version 0.19.2

* Tue Oct 06 2020 kekepower <kekepower> 0.19.1-1.mga8
+ Revision: 1632411
- Update to version 0.19.1

* Sun Oct 04 2020 kekepower <kekepower> 0.19.0-1.mga8
+ Revision: 1632190
- Update to version 0.19.0

* Tue Aug 11 2020 kekepower <kekepower> 0.18.3-2.mga8
+ Revision: 1613424
- Tighten up the description a little

* Tue Aug 11 2020 kekepower <kekepower> 0.18.3-1.mga8
+ Revision: 1613300
- Update to version 0.18.3

* Tue Jul 28 2020 kekepower <kekepower> 0.18.2-1.mga8
+ Revision: 1609433
- Disable tests for now
- Update to version 0.18.2

* Tue Jun 23 2020 kekepower <kekepower> 0.18.1-1.mga8
+ Revision: 1598782
- Update to version 0.18.1

* Sat Jun 20 2020 kekepower <kekepower> 0.18.0-1.mga8
+ Revision: 1598125
- Update to version 0.18.0

* Sat May 09 2020 kekepower <kekepower> 0.17.4-1.mga8
+ Revision: 1582363
- Update to version 0.17.4

* Thu Apr 23 2020 kekepower <kekepower> 0.17.3-1.mga8
+ Revision: 1571242
- Update to version 0.17.3

* Sun Mar 29 2020 kekepower <kekepower> 0.17.2-1.mga8
+ Revision: 1562144
- Update to version 0.17.2

* Tue Mar 24 2020 kekepower <kekepower> 0.17.1-1.mga8
+ Revision: 1559529
- Update to version 0.17.1

* Thu Feb 20 2020 umeabot <umeabot> 0.16.0-3.mga8
+ Revision: 1546131
- Mageia 8 Mass Rebuild
+ kekepower <kekepower>
- Bump rel

* Fri Jan 31 2020 kekepower <kekepower> 0.16.0-1.1.mga8
+ Revision: 1486120
- imported package kitty

